==> mono_1.1.12.1.orig.tar.gz: mono-1.1.12.1/mcs/class/System/Microsoft.Win32/IntranetZoneCredentialPolicy.cs <==
//
// Microsoft.Win32.IntranetZoneCredentialPolicy class
//
// Author:
//	Sebastien Pouliot  <sebastien@ximian.com>
//
// Copyright (C) 2005 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

#if NET_2_0

using System;
using System.Net;
using System.Security;
using System.Security.Permissions;
using System.Security.Policy;

namespace Microsoft.Win32 {

	public class IntranetZoneCredentialPolicy : ICredentialPolicy {

		[SecurityPermission (SecurityAction.Demand, ControlPolicy = true)]
		public IntranetZoneCredentialPolicy ()
		{
		}

		public virtual bool ShouldSendCredential (Uri challengeUri, WebRequest request,
			NetworkCredential credential, IAuthenticationModule authenticationModule)
		{
			Zone z = Zone.CreateFromUrl (challengeUri.AbsoluteUri);
			return (z.SecurityZone == SecurityZone.Intranet);
		}
	}
}

#endif

==> mono_4.6.2.7+dfsg.orig.tar.gz: mono-4.6.2+dfsg/mcs/class/System/Microsoft.Win32/IntranetZoneCredentialPolicy.cs <==
//
// Microsoft.Win32.IntranetZoneCredentialPolicy class
//
// Author:
//	Sebastien Pouliot  <sebastien@ximian.com>
//
// Copyright (C) 2005 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using System;
using System.Net;
using System.Security;
using System.Security.Permissions;
using System.Security.Policy;

namespace Microsoft.Win32 {

	public class IntranetZoneCredentialPolicy : ICredentialPolicy {

		[SecurityPermission (SecurityAction.Demand, ControlPolicy = true)]
		public IntranetZoneCredentialPolicy ()
		{
		}

		public virtual bool ShouldSendCredential (Uri challengeUri, WebRequest request,
			NetworkCredential credential, IAuthenticationModule authModule)
		{
			Zone z = Zone.CreateFromUrl (challengeUri.AbsoluteUri);
			return (z.SecurityZone == SecurityZone.Intranet);
		}
	}
}
